<!DOCTYPE html>
<html>
    <head>
        <link rel="stylesheet" href="styles.css">
    </head>
    <body>
        <div id="top">
          <img src="{{ logo_path }}" style="margin-top: -10px; margin-bottom: -10px; height: 80px">
        </div>
        <div id="main">
            <h1>Certificado</h1>
            <p>{{ organizer }} certifica que</p>
            <p style="text-align: center; font-size: 24px">{{ name }}</p>
            <p>participou do(a) {{ title }}, promovido pelo(a) {{ organizer }}, que aconteceu no(a) {{ place }}, no dia {{ date }}, com carga horária total de {{ workload }}.</p>
        </div>
        <div id="bot">
            <div style="margin: auto; width: 25%">
                <p>{{ city }}, {{ full_date }}</p>
                <img src="{{ signature_img_path }}" style="height: 60px">
                <div id="signature">
                    <p>{{ responsible }}<br/>{{ responsible_title }}</p>
                </div>
            </div>
        </div>
    </body>
</html>
